CropRect class

Model for setting detection area of recognizers.

If detection area is bigger than CameraPreview size, there won't any detection.

Constructors

CropRect({double scaleWidth = 1, double scaleHeight = 1, double offsetX = 0, double offsetY = 0})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
offsetX → double
X-axis offset in percentage from centerX of CameraPreview size rect.
final
offsetY → double
Y-axis offset in percentage from center Y of CameraPreview size rect.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleHeight → double
Height relative to height of the CameraPreview in percentage.
final
scaleWidth → double
Width relative to width of the CameraPreview in percentage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, double>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited