IosCamera class

Ios camera info.

Constructors

IosCamera({required IosCameraType type, required IosCameraPosition position})
const
IosCamera.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
position → IosCameraPosition
Camera position.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → IosCameraType
Camera type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited