IosScannerParameters class

Parameters for initializing the scanner on iOS.

Inheritance

Constructors

IosScannerParameters({double? zoom, IosCamera? camera, CropRect? cropRect})
const

Properties

camera → IosCamera?
Optional initial camera.
final
cropRect → CropRect?
Optional initial scanner overlay with CropRect of the detection area.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoom → double?
Optional initial zoom.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converting an object into a format for transferring to native.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited