setCropArea method

Future<void> setCropArea(
  1. CropRect rect
)

Sets the detection area for barcode recognition.

The rect parameter defines the crop area relative to the CameraPreview size using scale and offset values in percentage. If the detection area exceeds the CameraPreview bounds, no detection will occur.

Can throw PlatformException if camera is not initialized.

Implementation

Future<void> setCropArea(CropRect rect) async {
  return _barcodeScannerState?._setCropArea(rect);
}