CameraPreview class

Camera Preview of the device camera.

Widget automatically will dispose camera when called dispose in state.

Inheritance

Constructors

CameraPreview({Key? key, required VoidCallback onCameraInitialized, ScannerParameters? initialArguments, CameraInitilizeError? onCameraInitializeError})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialArguments → ScannerParameters?
Parameters for initializing the scanner.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCameraInitialized → VoidCallback
Callback when device camera initialize.
final
onCameraInitializeError → CameraInitilizeError?
Callback if camera cannot be initialized.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CameraPreviewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited